==> tempest_12.2.0.orig.tar.xz: tempest-12.2.0/tempest/api/compute/admin/test_availability_zone.py <==
# Copyright 2013 NEC Corporation
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from tempest.api.compute import base
from tempest import test


class AZAdminV2TestJSON(base.BaseV2ComputeAdminTest):
    """Tests Availability Zone API List"""

    @classmethod
    def setup_clients(cls):
        super(AZAdminV2TestJSON, cls).setup_clients()
        cls.client = cls.availability_zone_admin_client

    @test.idempotent_id('d3431479-8a09-4f76-aa2d-26dc580cb27c')
    def test_get_availability_zone_list(self):
        # List of availability zone
        availability_zone = self.client.list_availability_zones()
        self.assertTrue(len(availability_zone['availabilityZoneInfo']) > 0)

    @test.idempotent_id('ef726c58-530f-44c2-968c-c7bed22d5b8c')
    def test_get_availability_zone_list_detail(self):
        # List of availability zones and available services
        availability_zone = self.client.list_availability_zones(detail=True)
        self.assertTrue(len(availability_zone['availabilityZoneInfo']) > 0)

==> tempest_41.0.0.orig.tar.xz: tempest-41.0.0/tempest/api/compute/admin/test_availability_zone.py <==
# Copyright 2013 NEC Corporation
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from tempest.api.compute import base
from tempest.lib import decorators


class AZAdminV2TestJSON(base.BaseV2ComputeAdminTest):
    """Tests Availability Zone API List"""

    @classmethod
    def setup_clients(cls):
        super(AZAdminV2TestJSON, cls).setup_clients()
        cls.client = cls.availability_zone_admin_client

    @decorators.idempotent_id('d3431479-8a09-4f76-aa2d-26dc580cb27c')
    def test_get_availability_zone_list(self):
        """Test listing availability zones"""
        availability_zone = self.client.list_availability_zones()
        self.assertNotEmpty(availability_zone['availabilityZoneInfo'])

    @decorators.idempotent_id('ef726c58-530f-44c2-968c-c7bed22d5b8c')
    def test_get_availability_zone_list_detail(self):
        """Test listing availability zones with detail"""
        availability_zone = self.client.list_availability_zones(detail=True)
        self.assertNotEmpty(availability_zone['availabilityZoneInfo'])
